@@ -6,6 +6,7 @@ import geogebra.kernel.GeoBoolean;
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.GeoFunction;
 import geogebra.kernel.GeoList;
+import geogebra.kernel.GeoText;
 import geogebra.kernel.Kernel;
 import geogebra.main.Application;
 
@@ -269,6 +270,9 @@ public class RelativeCopy {
 		}
 		String text = null;
 		
+		// make sure a/0.001 doesn't become a/0
+		kernel.setTemporaryPrintFigures(15);
+		
 		if (value.isPointOnPath()) {
 			text = value.getCommandDescription();
 		}
@@ -279,6 +283,10 @@ public class RelativeCopy {
 			text = value.getCommandDescription(); 
 		}
 		
+		// enclose in quotes if we are copying a GeoText
+		if(value.isGeoText() && !((GeoText)value).isTextCommand()){
+			text = "\"" + text + "\"";
+		}
 		
 		// for E1 = Polynomial[D1] we need value.getCommandDescription(); 
 		// even though it's a GeoFunction
@@ -321,6 +329,8 @@ public class RelativeCopy {
 			
 		// allow pasting blank strings
 		if (text.equals("")) text = "\"\"";
+		
+		kernel.restorePrintAccuracy();
 
 		//Application.debug("add text = " + text + ", name = " + (char)('A' + column + dx) + (row + dy + 1));
 		//int column3 = table.convertColumnIndexToView(column) + dx;
