@@ -58,6 +58,7 @@ import java.util.LinkedHashMap;
 import java.util.LinkedList;
 
 import javax.swing.JComponent;
+import javax.swing.SwingUtilities;
 
 import org.xml.sax.SAXException;
 
@@ -334,8 +335,13 @@ public class MyXMLHandler implements DocHandler {
 			if (eName.equals("geogebra")) {
 				
 				// start animation if necessary
-				if (startAnimation)
-					kernel.getAnimatonManager().startAnimation();
+				if (startAnimation) {
+					if (app.isApplet())
+						// start later, in initInBackground()
+						kernel.setWantAnimationStarted(true);
+					else
+						kernel.getAnimatonManager().startAnimation();					
+				}
 			}
 		}
 	}
