@@ -31,7 +31,7 @@ implements Locateable, AbsoluteScreenLocateable,
 	private GeoPoint [] corners; // corners of the image
 	private BufferedImage image;	
 	private int pixelWidth, pixelHeight;
-	private boolean inBackground;
+	private boolean inBackground, defined;
 	private boolean hasAbsoluteLocation;
 	
 	// for absolute screen location
@@ -51,7 +51,8 @@ implements Locateable, AbsoluteScreenLocateable,
 		// three corners of the image: first, second and fourth
 		corners = new GeoPoint[3]; 			
 				
-		instances.add(this);						
+		instances.add(this);
+		defined = true;
 	}  
 
 	
@@ -114,6 +115,7 @@ implements Locateable, AbsoluteScreenLocateable,
 				}
 			}
 		}
+		defined = img.defined;
 	}
 	
 	public void setVisualStyle(GeoElement geo) {
@@ -310,6 +312,7 @@ implements Locateable, AbsoluteScreenLocateable,
 	}
 
 	final public boolean isDefined() {
+		if(!defined) return false;
 		for (int i=0; i < corners.length; i++) {
 			if (corners[i] != null  && !corners[i].isDefined())
 					return false;
@@ -318,9 +321,11 @@ implements Locateable, AbsoluteScreenLocateable,
 	}
 
 	/**
-	 * doesn't do anything
+	 * makes image invisible 
+	 * needed for Sequence's cached images 
  	*/
 	public void setUndefined() {
+		defined = false;		
 	}
 
 	public String toValueString() {
