@@ -361,7 +361,12 @@ Translateable, PointRotateable, Mirrorable, Dilateable, PointProperties {
     
 	final public boolean isDefined() { 
 		return isDefined;        
-	}     
+	}    
+	
+    public void setUndefined() {    
+    	super.setUndefined();
+    	isDefined = false;
+    }       
 	
 	final public boolean isFixable() {
 		return path != null || super.isFixable();
