@@ -239,6 +239,10 @@ final public class GeoPolygon extends GeoElement implements NumberValue, Path {
                 segments[i].setObjColor(getObjectColor()); 
                 segments[i].setLineThickness(getLineThickness()); 
                 segments[i].setEuclidianVisible(i == 0 ? isEuclidianVisible() : segments[0].isEuclidianVisible());
+        		if (condShowObject != null) {
+        			try { ((GeoElement)segments[i]).setShowObjectCondition(getShowObjectCondition());}
+        			catch (Exception e) {}
+        		}
                 //segments[i].setAuxiliaryObject(true);
         	}     
         }         
@@ -264,7 +268,6 @@ final public class GeoPolygon extends GeoElement implements NumberValue, Path {
 	public void set(GeoElement geo) {
 		GeoPolygon poly = (GeoPolygon) geo;		
 		area = poly.area;
-		defined = poly.defined;	
 		
 		// make sure both arrays have same size
 		if (points.length != poly.points.length) {
@@ -279,6 +282,7 @@ final public class GeoPolygon extends GeoElement implements NumberValue, Path {
 			points[i].set(poly.points[i]);
 		}	
 		updateSegments();
+		defined = poly.defined;	
 	}
 
 	/**
