@@ -15,7 +15,7 @@ public class DefaultApplication extends Application {
     	super(args, applet, undoActive);
     }
     
-    public DefaultApplication(String[] args, Container parentComponent, boolean undoActive) {
-    	super(args, parentComponent, undoActive);
+    public DefaultApplication(String[] args, Container parentComponent, boolean undoActive, String externalCodebase) {
+    	super(args, parentComponent, undoActive, externalCodebase);
     }
 }
