@@ -198,6 +198,12 @@ public class GlobalKeyDispatcher implements KeyEventDispatcher {
 				}
 				break;
 			
+				// Ctrl + E: open object properties (needed here for spreadsheet)
+			case KeyEvent.VK_E:
+				app.getGuiManager().showPropertiesDialog();
+				consumed = true;								
+				break;
+				
 			// Ctrl + F: refresh views
 			case KeyEvent.VK_F:
 				app.refreshViews();
